//
//  ContactsTableViewController.swift
//  PhoneBook
//
//  Created by Santiago Pavón Gómez on 30/11/16.
//  Copyright © 2016 UPM. All rights reserved.
//

import UIKit

class ContactsTableViewController: UITableViewController {

    private let CONTACTSBOOK_FILENAME = "agenda.plist"
    
    private var contactsBook = ContactsBook()
    
    override func viewDidLoad() {
        super.viewDidLoad()

        // Uncomment the following line to preserve selection between presentations
        // self.clearsSelectionOnViewWillAppear = false

        // Uncomment the following line to display an Edit button in the navigation bar for this view controller.
        self.navigationItem.leftBarButtonItem = self.editButtonItem
   
        contactsBook.loadOrCreate(from: CONTACTSBOOK_FILENAME)
    
    }

    override func didReceiveMemoryWarning() {
        super.didReceiveMemoryWarning()
        // Dispose of any resources that can be recreated.
    }

    // MARK: - Table view data source

    override func numberOfSections(in tableView: UITableView) -> Int {
        return 1
    }

    override func tableView(_ tableView: UITableView, numberOfRowsInSection section: Int) -> Int {
        return contactsBook.contacts.count
    }

    override func tableView(_ tableView: UITableView, cellForRowAt indexPath: IndexPath) -> UITableViewCell {
        let cell = tableView.dequeueReusableCell(withIdentifier: "Contact Cell", for: indexPath) as! ContactCell

        let contact = contactsBook.contacts[indexPath.row]
        
        cell.nameLabel.text = contact.name
        cell.addressLabel.text = contact.address
        cell.phoneLabel.text = contact.phone
        
        return cell
    }


    /*
    // Override to support conditional editing of the table view.
    override func tableView(_ tableView: UITableView, canEditRowAt indexPath: IndexPath) -> Bool {
        // Return false if you do not want the specified item to be editable.
        return true
    }
    */

    // Override to support editing the table view.
    override func tableView(_ tableView: UITableView, commit editingStyle: UITableViewCellEditingStyle, forRowAt indexPath: IndexPath) {
      
        if editingStyle == .delete {
            
            // Delete the row from the data source
            contactsBook.contacts.remove(at: indexPath.row)
            
            contactsBook.save(to: CONTACTSBOOK_FILENAME)
            
            tableView.deleteRows(at: [indexPath], with: .fade)
       
        } else if editingStyle == .insert {
            
            // Create a new instance of the appropriate class, insert it into the array, and add a new row to the table view
        }    
    }

    /*
    // Override to support rearranging the table view.
    override func tableView(_ tableView: UITableView, moveRowAt fromIndexPath: IndexPath, to: IndexPath) {

    }
    */

    /*
    // Override to support conditional rearranging of the table view.
    override func tableView(_ tableView: UITableView, canMoveRowAt indexPath: IndexPath) -> Bool {
        // Return false if you do not want the item to be re-orderable.
        return true
    }
    */

    // MARK: - Navigation

    override func prepare(for segue: UIStoryboardSegue, sender: Any?) {
        
        if segue.identifier == "Editing Contact" {

            if let ecvc = segue.destination as? EditContactTableViewController,
                let ip = tableView.indexPathForSelectedRow {
                ecvc.contact = contactsBook.contacts[ip.row]
            }
        } else if segue.identifier == "Adding Contact" {
            
            if let ecvc = segue.destination as? EditContactTableViewController {
                
                let newContact = Contact(name: "", address: "", phone: "")
                contactsBook.contacts.insert(newContact, at: 0)
                
                let ip = IndexPath(row: 0, section: 0)
                tableView.insertRows(at: [ip], with: .automatic)
                
                tableView.selectRow(at: ip, animated: true, scrollPosition: .top)
                
                ecvc.contact = newContact
            }
        }

    }

    
    @IBAction func contactWasChanged(_ segue: UIStoryboardSegue) {
        
        if let ip = tableView.indexPathForSelectedRow {
         
            tableView.reloadRows(at: [ip], with: .automatic)

            contactsBook.save(to: CONTACTSBOOK_FILENAME)

        }
    }
}



















